ApiInspectorInterceptor class

Dio interceptor that records requests/responses/errors into an ApiInspectorService.

Automatically acts as a transparent pass-through in release mode so it adds zero overhead to production builds. Pair this with ApiInspectorOverlay + ApiInspectorController to get a tap-driven capture UI.

Constructors

ApiInspectorInterceptor(ApiInspectorService _inspector)
Creates an ApiInspectorInterceptor backed by inspector.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) → void
Called when an exception was occurred during the request.
onRequest(RequestOptions options, RequestInterceptorHandler handler) → void
Called when the request is about to be sent.
onResponse(Response response, ResponseInterceptorHandler handler) → void
Called when the response is about to be resolved.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited