showDoneErrorCountInLabel property
When true, the error count is shown inside the bubble after recording finishes.
Implementation
final bool showDoneErrorCountInLabel;
When true, the error count is shown inside the bubble after recording finishes.
final bool showDoneErrorCountInLabel;