showRequestCountInLabel property
When true, the captured request count is shown inside the bubble while recording.
Implementation
final bool showRequestCountInLabel;
When true, the captured request count is shown inside the bubble while recording.
final bool showRequestCountInLabel;