api_inspector library
Dio API Inspector overlay library for Flutter. Co-authored and inspired by Safal Shrestha.
Classes
- ApiCallDetailScreen
- Detail screen for a single ApiCallRecord.
- ApiCallRecord
- Lightweight record of a single captured API call.
- ApiCallsListScreen
- Screen that displays a list of captured ApiCallRecords.
- ApiInspectorController
- Coordinates the API inspector capture window and navigation to the UI.
- ApiInspectorDone
- Inspector has finished recording and has captured records.
- ApiInspectorIdle
- Inspector is idle (not recording and no completed results).
- ApiInspectorInterceptor
- Dio interceptor that records requests/responses/errors into an ApiInspectorService.
- ApiInspectorOverlay
- Drop-in overlay that shows/hides based on ApiInspectorController.
- ApiInspectorRecording
- Inspector is currently recording calls for a limited time window.
- ApiInspectorService
- Holds recorded ApiCallRecords during a capture session.
- ApiInspectorState
- Base type for API inspector UI state.