ApiInspectorService class
Holds recorded ApiCallRecords during a capture session.
Record accumulation is guarded by isRecording so there is minimal overhead when the inspector is not active.
Constructors
Properties
- activeSessionId → int?
-
Active session id, or
nullwhen not recording.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- isRecording → bool
-
Whether a capture session is currently active.
no setter
-
records
→ List<
ApiCallRecord> -
Immutable view of captured records.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void - Clears all captured records.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
record(
ApiCallRecord record, {int? sessionId}) → void - No-ops instantly if isRecording is false.
-
startRecording(
) → void - Starts a new recording session and clears any previously captured records.
-
stopRecording(
) → void - Stops the current recording session without clearing records.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited